#[repr(i32)]pub enum ServiceArgType {
Bool = 0,
Int = 1,
Float = 2,
String = 3,
BoolArray = 4,
IntArray = 5,
FloatArray = 6,
StringArray = 7,
}Expand description
==================== USER-DEFINES SERVICES ====================
Variants
Implementations
Sourceimpl ServiceArgType
impl ServiceArgType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.