pub struct ClimateStateResponse {Show 15 fields
pub key: u32,
pub mode: i32,
pub current_temperature: f32,
pub target_temperature: f32,
pub target_temperature_low: f32,
pub target_temperature_high: f32,
pub unused_legacy_away: bool,
pub action: i32,
pub fan_mode: i32,
pub swing_mode: i32,
pub custom_fan_mode: String,
pub preset: i32,
pub custom_preset: String,
pub current_humidity: f32,
pub target_humidity: f32,
}Fields
key: u32mode: i32current_temperature: f32target_temperature: f32target_temperature_low: f32target_temperature_high: f32unused_legacy_away: boolaction: i32fan_mode: i32swing_mode: i32custom_fan_mode: Stringpreset: i32custom_preset: Stringcurrent_humidity: f32target_humidity: f32Implementations
Sourceimpl ClimateStateResponse
impl ClimateStateResponse
Sourcepub fn mode(&self) -> ClimateMode
pub fn mode(&self) -> ClimateMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: ClimateMode)
pub fn set_mode(&mut self, value: ClimateMode)
Sets mode to the provided enum value.
Sourcepub fn action(&self) -> ClimateAction
pub fn action(&self) -> ClimateAction
Returns the enum value of action, or the default if the field is set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: ClimateAction)
pub fn set_action(&mut self, value: ClimateAction)
Sets action to the provided enum value.
Sourcepub fn fan_mode(&self) -> ClimateFanMode
pub fn fan_mode(&self) -> ClimateFanMode
Returns the enum value of fan_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_fan_mode(&mut self, value: ClimateFanMode)
pub fn set_fan_mode(&mut self, value: ClimateFanMode)
Sets fan_mode to the provided enum value.
Sourcepub fn swing_mode(&self) -> ClimateSwingMode
pub fn swing_mode(&self) -> ClimateSwingMode
Returns the enum value of swing_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_swing_mode(&mut self, value: ClimateSwingMode)
pub fn set_swing_mode(&mut self, value: ClimateSwingMode)
Sets swing_mode to the provided enum value.
Sourcepub fn preset(&self) -> ClimatePreset
pub fn preset(&self) -> ClimatePreset
Returns the enum value of preset, or the default if the field is set to an invalid enum value.
Sourcepub fn set_preset(&mut self, value: ClimatePreset)
pub fn set_preset(&mut self, value: ClimatePreset)
Sets preset to the provided enum value.