ListEntitiesClimateResponse

Struct ListEntitiesClimateResponse 

pub struct ListEntitiesClimateResponse {
Show 25 fields pub object_id: String, pub key: u32, pub name: String, pub unique_id: String, pub supports_current_temperature: bool, pub supports_two_point_target_temperature: bool, pub supported_modes: Vec<i32>, pub visual_min_temperature: f32, pub visual_max_temperature: f32, pub visual_target_temperature_step: f32, pub legacy_supports_away: bool, pub supports_action: bool, pub supported_fan_modes: Vec<i32>, pub supported_swing_modes: Vec<i32>, pub supported_custom_fan_modes: Vec<String>, pub supported_presets: Vec<i32>, pub supported_custom_presets: Vec<String>, pub disabled_by_default: bool, pub icon: String, pub entity_category: i32, pub visual_current_temperature_step: f32, pub supports_current_humidity: bool, pub supports_target_humidity: bool, pub visual_min_humidity: f32, pub visual_max_humidity: f32,
}

Fields

object_id: Stringkey: u32name: Stringunique_id: Stringsupports_current_temperature: boolsupports_two_point_target_temperature: boolsupported_modes: Vec<i32>visual_min_temperature: f32visual_max_temperature: f32visual_target_temperature_step: f32legacy_supports_away: bool

for older peer versions - in new system this is if CLIMATE_PRESET_AWAY exists is supported_presets

supports_action: boolsupported_fan_modes: Vec<i32>supported_swing_modes: Vec<i32>supported_custom_fan_modes: Vec<String>supported_presets: Vec<i32>supported_custom_presets: Vec<String>disabled_by_default: boolicon: Stringentity_category: i32visual_current_temperature_step: f32supports_current_humidity: boolsupports_target_humidity: boolvisual_min_humidity: f32visual_max_humidity: f32

Implementations

Source

impl ListEntitiesClimateResponse

pub fn supported_modes( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ClimateMode>>

Returns an iterator which yields the valid enum values contained in supported_modes.

pub fn push_supported_modes(&mut self, value: ClimateMode)

Appends the provided enum value to supported_modes.

pub fn supported_fan_modes( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ClimateFanMode>>

Returns an iterator which yields the valid enum values contained in supported_fan_modes.

pub fn push_supported_fan_modes(&mut self, value: ClimateFanMode)

Appends the provided enum value to supported_fan_modes.

pub fn supported_swing_modes( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ClimateSwingMode>>

Returns an iterator which yields the valid enum values contained in supported_swing_modes.

pub fn push_supported_swing_modes(&mut self, value: ClimateSwingMode)

Appends the provided enum value to supported_swing_modes.

pub fn supported_presets( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ClimatePreset>>

Returns an iterator which yields the valid enum values contained in supported_presets.

pub fn push_supported_presets(&mut self, value: ClimatePreset)

Appends the provided enum value to supported_presets.

pub fn entity_category(&self) -> EntityCategory

Returns the enum value of entity_category, or the default if the field is set to an invalid enum value.

pub fn set_entity_category(&mut self, value: EntityCategory)

Sets entity_category to the provided enum value.