pub struct ListEntitiesNumberResponse {}Fields
object_id: Stringkey: u32name: Stringunique_id: Stringicon: Stringmin_value: f32max_value: f32step: f32disabled_by_default: boolentity_category: i32unit_of_measurement: Stringmode: i32device_class: StringImplementations
Sourceimpl ListEntitiesNumberResponse
impl ListEntitiesNumberResponse
Sourcepub fn entity_category(&self) -> EntityCategory
pub fn entity_category(&self) -> EntityCategory
Returns the enum value of entity_category, or the default if the field is set to an invalid enum value.
Sourcepub fn set_entity_category(&mut self, value: EntityCategory)
pub fn set_entity_category(&mut self, value: EntityCategory)
Sets entity_category to the provided enum value.
Sourcepub fn mode(&self) -> NumberMode
pub fn mode(&self) -> NumberMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: NumberMode)
pub fn set_mode(&mut self, value: NumberMode)
Sets mode to the provided enum value.